==> marketplace-constants-0.1.4.7.tar.gz: marketplace-constants-0.1.4.7/mpconstants/regions/hr.py <==
REGIONS = {u'ad': u'Andora',
 u'ae': u'U.A.E.',
 u'af': u'Afganistan',
 u'ag': u'Antigua i Barbuda',
 u'ai': u'Anguila',
 u'al': u'Albanija',
 u'am': u'Armenija',
 u'an': u'Nizozmski Antili',
 u'ao': u'Angola',
 u'aq': u'Antarctika',
 u'ar': u'Argentina',
 u'as': u'Ameri\u010dka Samoa',
 u'at': u'Austrija',
 u'au': u'Australija',
 u'aw': u'Aruba',
 u'ax': u'\\u00c5land Otoci',
 u'az': u'Azerbajd\u017ean',
 u'ba': u'Bosna i Hercegovina',
 u'bb': u'Barbados',
 u'bd': u'Banglade\u0161',
 u'be': u'Belgija',
 u'bf': u'Burkina Faso',
 u'bg': u'Bugarska',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Sveti Barth\\u00e9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunej',
 u'bo': u'Bolivija',
 u'br': u'Brazil',
 u'bs': u'Bahami',
 u'bt': u'Butan',
 u'bv': u'Bouvet Otok',
 u'bw': u'Bocvana',
 u'by': u'Bjelorusija',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Cookovo Oto\u010dje (Keeling)',
 u'cd': u'Kongo-Kin\u0161asa',
 u'cf': u'Centralna Afri\u010dka Republika',
 u'cg': u'Kongo-Brazzaville',
 u'ch': u'\u0160vicarska',
 u'ci': u'Obala Bjelokosti',
 u'ck': u'Cookovo Oto\u010dje',
 u'cl': u'\u010cile',
 u'cm': u'Kamerun',
 u'cn': u'Kina',
 u'co': u'Kolumbija',
 u'cr': u'Kostarika',
 u'cu': u'Kuba',
 u'cv': u'Cape Verde',
 u'cx': u'Bo\u017ei\u010dno Oto\u010dje',
 u'cy': u'Cipar',
 u'cz': u'\u010ce\u0161ka Republika',
 u'de': u'Njema\u010dka',
 u'dj': u'Djibouti',
 u'dk': u'Danska',
 u'dm': u'Dominika',
 u'do': u'Dominikanska Republika',
 u'dz': u'Al\u017eir',
 u'ec': u'Ekvador',
 u'ee': u'Estonija',
 u'eg': u'Egipat',
 u'eh': u'Zapadna Sahara',
 u'er': u'Eritreja',
 u'es': u'\u0160panjolska',
 u'et': u'Etiopija',
 u'fi': u'Finska',
 u'fj': u'Fid\u017ei',
 u'fk': u'Falklandsko Oto\u010dje (Malvinas)',
 u'fm': u'Mikronezija',
 u'fo': u'Faroe Oto\u010dje',
 u'fr': u'Francuska',
 u'ga': u'Gabon',
 u'gb': u'Ujedinjeno Kraljevstvo',
 u'gd': u'Grenada',
 u'ge': u'Gruzija',
 u'gf': u'Francuska Gvajana',
 u'gg': u'Guernsey',
 u'gh': u'Gana',
 u'gi': u'Gibraltar',
 u'gl': u'Grenland',
 u'gm': u'Gambija',
 u'gn': u'Gvineja',
 u'gp': u'Guadeloupe',
 u'gq': u'Ekvatorska Gvineja',
 u'gr': u'Gr\u010dka',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'Gvatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Gvajana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'Honduras',
 u'hr': u'Hrvatska',
 u'ht': u'Haiti',
 u'hu': u'Ma\u0111arska',
 u'id': u'Indonezija',
 u'ie': u'Irska',
 u'il': u'Izrael',
 u'im': u'Otok \u010covjeka',
 u'in': u'Indija',
 u'io': u'Teritorij Britanskog Indijskog Oceana',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Island',
 u'it': u'Italija',
 u'je': u'Jersey',
 u'jm': u'Jamajka',
 u'jo': u'Jordan',
 u'jp': u'Japan',
 u'ke': u'Kenija',
 u'kg': u'Kirgistan',
 u'kh': u'Kambod\u017ea',
 u'ki': u'Kiribati',
 u'km': u'Komori',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'Sjeverna Koreja',
 u'kr': u'Ju\u017ena Koreja',
 u'kw': u'Kuvajt',
 u'ky': u'Kajmansko Oto\u010dje',
 u'kz': u'Kazakstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Sveta Lucija',
 u'li': u'Lihten\u0161tajn',
 u'lk': u'\u0160ri Lanka',
 u'lr': u'Liberija',
 u'ls': u'Lesoto',
 u'lt': u'Litva',
 u'lu': u'Luksemburg',
 u'lv': u'Latvija',
 u'ly': u'Libija',
 u'ma': u'Maroko',
 u'mc': u'Monako',
 u'md': u'Moldavija',
 u'me': u'Crna Gora',
 u'mf': u'Sveti Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshallovo Oto\u010dje',
 u'mk': u'Makedonija',
 u'ml': u'Mali',
 u'mm': u'Mijanmar',
 u'mn': u'Mongolija',
 u'mo': u'Makao',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinik',
 u'mr': u'Mauritanija',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauricijus',
 u'mv': u'Maldivi',
 u'mw': u'Malawi',
 u'mx': u'Meksiko',
 u'my': u'Malezija',
 u'mz': u'Mozambik',
 u'na': u'Namibija',
 u'nc': u'Nova Kaledonija',
 u'ne': u'Niger',
 u'nf': u'Norfolk Oto\u010dje',
 u'ng': u'Nigerija',
 u'ni': u'Nikaragva',
 u'nl': u'Nizozmeska',
 u'no': u'Norve\u0161ka',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Novi Zeland',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Francuska Polinezija',
 u'pg': u'Papua New Guinea',
 u'ph': u'Filipini',
 u'pk': u'Pakistan',
 u'pl': u'Poljska',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Portoriko',
 u'ps': u'Okupirani Palestinski Teritorij',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paragvaj',
 u'qa': u'Katar',
 u're': u'Reunion',
 u'ro': u'Rumunjska',
 u'rs': u'Srbija',
 u'ru': u'Rusija',
 u'rw': u'Ruanda',
 u'sa': u'Saudijska Arabija',
 u'sb': u'Solomon Oto\u010dje',
 u'sc': u'Sej\u0161eli',
 u'sd': u'Sudan',
 u'se': u'\u0160vedska',
 u'sg': u'Singapur',
 u'sh': u'Sveta Helena',
 u'si': u'Slovenija',
 u'sj': u'Svalbard and Jan Mayen',
 u'sk': u'Slova\u010dka',
 u'sl': u'Siera Leon',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalija',
 u'sr': u'Surinam',
 u'st': u'Sao Tome i Principe',
 u'sv': u'Salvador',
 u'sy': u'Sirija',
 u'sz': u'Swaziland',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'\u010cad',
 u'tf': u'Francuski Ju\u017ei Teritoriji',
 u'tg': u'Togo',
 u'th': u'Tajland',
 u'tj': u'Tad\u017eikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunis',
 u'to': u'Tonga',
 u'tr': u'Turska',
 u'tt': u'Trinidad i Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Tajvan',
 u'tz': u'Tanzania',
 u'ua': u'Ukrajina',
 u'ug': u'Uganda',
 u'um': u'Mali Izba\u010deni Otoci Sjedinjenih Dr\u017eava',
 u'us': u'Sjedinjene Dr\u017eave',
 u'uy': u'Urugvaj',
 u'uz': u'Uzbekistan',
 u'va': u'Vatican',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venecuela',
 u'vg': u'Britansko Djevi\u010dansko Oto\u010dje',
 u'vi': u'U.S. Djevi\u010dansko Oto\u010dje',
 u'vn': u'Vijetnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'Ju\u017enoafri\u010dka Republika',
 u'zm': u'Zambia',
 u'zw': u'Zimbabve'}

==> marketplace-constants-0.3.2.tar.gz: marketplace-constants-0.3.2/mpconstants/regions/hr.py <==
REGIONS = {u'ad': u'Andora',
 u'ae': u'U.A.E.',
 u'af': u'Afganistan',
 u'ag': u'Antigua i Barbuda',
 u'ai': u'Anguila',
 u'al': u'Albanija',
 u'am': u'Armenija',
 u'an': u'Nizozmski Antili',
 u'ao': u'Angola',
 u'aq': u'Antarctika',
 u'ar': u'Argentina',
 u'as': u'Ameri\u010dka Samoa',
 u'at': u'Austrija',
 u'au': u'Australija',
 u'aw': u'Aruba',
 u'ax': u'\xc5land Otoci',
 u'az': u'Azerbajd\u017ean',
 u'ba': u'Bosna i Hercegovina',
 u'bb': u'Barbados',
 u'bd': u'Banglade\u0161',
 u'be': u'Belgija',
 u'bf': u'Burkina Faso',
 u'bg': u'Bugarska',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Sveti Barth\xe9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunej',
 u'bo': u'Bolivija',
 u'br': u'Brazil',
 u'bs': u'Bahami',
 u'bt': u'Butan',
 u'bv': u'Bouvet Otok',
 u'bw': u'Bocvana',
 u'by': u'Bjelorusija',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Cookovo Oto\u010dje (Keeling)',
 u'cd': u'Kongo-Kin\u0161asa',
 u'cf': u'Centralna Afri\u010dka Republika',
 u'cg': u'Kongo-Brazzaville',
 u'ch': u'\u0160vicarska',
 u'ci': u'Obala Bjelokosti',
 u'ck': u'Cookovo Oto\u010dje',
 u'cl': u'\u010cile',
 u'cm': u'Kamerun',
 u'cn': u'Kina',
 u'co': u'Kolumbija',
 u'cr': u'Kostarika',
 u'cu': u'Kuba',
 u'cv': u'Cape Verde',
 u'cx': u'Bo\u017ei\u010dno Oto\u010dje',
 u'cy': u'Cipar',
 u'cz': u'\u010ce\u0161ka Republika',
 u'de': u'Njema\u010dka',
 u'dj': u'Djibouti',
 u'dk': u'Danska',
 u'dm': u'Dominika',
 u'do': u'Dominikanska Republika',
 u'dz': u'Al\u017eir',
 u'ec': u'Ekvador',
 u'ee': u'Estonija',
 u'eg': u'Egipat',
 u'eh': u'Zapadna Sahara',
 u'er': u'Eritreja',
 u'es': u'\u0160panjolska',
 u'et': u'Etiopija',
 u'fi': u'Finska',
 u'fj': u'Fid\u017ei',
 u'fk': u'Falklandsko Oto\u010dje (Malvinas)',
 u'fm': u'Mikronezija',
 u'fo': u'Faroe Oto\u010dje',
 u'fr': u'Francuska',
 u'ga': u'Gabon',
 u'gb': u'Ujedinjeno Kraljevstvo',
 u'gd': u'Grenada',
 u'ge': u'Gruzija',
 u'gf': u'Francuska Gvajana',
 u'gg': u'Guernsey',
 u'gh': u'Gana',
 u'gi': u'Gibraltar',
 u'gl': u'Grenland',
 u'gm': u'Gambija',
 u'gn': u'Gvineja',
 u'gp': u'Guadeloupe',
 u'gq': u'Ekvatorska Gvineja',
 u'gr': u'Gr\u010dka',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'Gvatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Gvajana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'Honduras',
 u'hr': u'Hrvatska',
 u'ht': u'Haiti',
 u'hu': u'Ma\u0111arska',
 u'id': u'Indonezija',
 u'ie': u'Irska',
 u'il': u'Izrael',
 u'im': u'Otok \u010covjeka',
 u'in': u'Indija',
 u'io': u'Teritorij Britanskog Indijskog Oceana',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Island',
 u'it': u'Italija',
 u'je': u'Jersey',
 u'jm': u'Jamajka',
 u'jo': u'Jordan',
 u'jp': u'Japan',
 u'ke': u'Kenija',
 u'kg': u'Kirgistan',
 u'kh': u'Kambod\u017ea',
 u'ki': u'Kiribati',
 u'km': u'Komori',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'Sjeverna Koreja',
 u'kr': u'Ju\u017ena Koreja',
 u'kw': u'Kuvajt',
 u'ky': u'Kajmansko Oto\u010dje',
 u'kz': u'Kazakstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Sveta Lucija',
 u'li': u'Lihten\u0161tajn',
 u'lk': u'\u0160ri Lanka',
 u'lr': u'Liberija',
 u'ls': u'Lesoto',
 u'lt': u'Litva',
 u'lu': u'Luksemburg',
 u'lv': u'Latvija',
 u'ly': u'Libija',
 u'ma': u'Maroko',
 u'mc': u'Monako',
 u'md': u'Moldavija',
 u'me': u'Crna Gora',
 u'mf': u'Sveti Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshallovo Oto\u010dje',
 u'mk': u'Makedonija',
 u'ml': u'Mali',
 u'mm': u'Mijanmar',
 u'mn': u'Mongolija',
 u'mo': u'Makao',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinik',
 u'mr': u'Mauritanija',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauricijus',
 u'mv': u'Maldivi',
 u'mw': u'Malawi',
 u'mx': u'Meksiko',
 u'my': u'Malezija',
 u'mz': u'Mozambik',
 u'na': u'Namibija',
 u'nc': u'Nova Kaledonija',
 u'ne': u'Niger',
 u'nf': u'Norfolk Oto\u010dje',
 u'ng': u'Nigerija',
 u'ni': u'Nikaragva',
 u'nl': u'Nizozmeska',
 u'no': u'Norve\u0161ka',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Novi Zeland',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Francuska Polinezija',
 u'pg': u'Papua New Guinea',
 u'ph': u'Filipini',
 u'pk': u'Pakistan',
 u'pl': u'Poljska',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Portoriko',
 u'ps': u'Okupirani Palestinski Teritorij',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paragvaj',
 u'qa': u'Katar',
 u're': u'Reunion',
 u'ro': u'Rumunjska',
 u'rs': u'Srbija',
 u'ru': u'Rusija',
 u'rw': u'Ruanda',
 u'sa': u'Saudijska Arabija',
 u'sb': u'Solomon Oto\u010dje',
 u'sc': u'Sej\u0161eli',
 u'sd': u'Sudan',
 u'se': u'\u0160vedska',
 u'sg': u'Singapur',
 u'sh': u'Sveta Helena',
 u'si': u'Slovenija',
 u'sj': u'Svalbard and Jan Mayen',
 u'sk': u'Slova\u010dka',
 u'sl': u'Siera Leon',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalija',
 u'sr': u'Surinam',
 u'st': u'Sao Tome i Principe',
 u'sv': u'Salvador',
 u'sy': u'Sirija',
 u'sz': u'Swaziland',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'\u010cad',
 u'tf': u'Francuski Ju\u017ei Teritoriji',
 u'tg': u'Togo',
 u'th': u'Tajland',
 u'tj': u'Tad\u017eikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunis',
 u'to': u'Tonga',
 u'tr': u'Turska',
 u'tt': u'Trinidad i Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Tajvan',
 u'tz': u'Tanzania',
 u'ua': u'Ukrajina',
 u'ug': u'Uganda',
 u'um': u'Mali Izba\u010deni Otoci Sjedinjenih Dr\u017eava',
 u'us': u'Sjedinjene Dr\u017eave',
 u'uy': u'Urugvaj',
 u'uz': u'Uzbekistan',
 u'va': u'Vatican',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venecuela',
 u'vg': u'Britansko Djevi\u010dansko Oto\u010dje',
 u'vi': u'U.S. Djevi\u010dansko Oto\u010dje',
 u'vn': u'Vijetnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'Ju\u017enoafri\u010dka Republika',
 u'zm': u'Zambia',
 u'zw': u'Zimbabve'}
